@@ -137,7 +137,7 @@ Preset::~Preset()
 
 void Preset::loadSamples()
       {
-//      sfont->synth->mutex.lock();
+      bool locked = sfont->synth->mutex.tryLock();
       if (_global_zone && _global_zone->instrument) {
             Instrument* i = _global_zone->instrument;
             if (i->global_zone && i->global_zone->sample)
@@ -153,7 +153,8 @@ void Preset::loadSamples()
             foreach(Zone* iz, i->zones)
                   iz->sample->load();
             }
-//      sfont->synth->mutex.unlock();
+      if (locked)
+            sfont->synth->mutex.unlock();
       }
 
 //---------------------------------------------------------
