@@ -888,10 +888,11 @@ Element* ChordRest::drop(const DropData& data)
                   Note* note = static_cast<Note*>(e);
                   NoteVal nval;
                   nval.pitch = note->pitch();
+                  nval.tpc1 = note->tpc1();
                   nval.headGroup = note->headGroup();
                   nval.fret = note->fret();
                   nval.string = note->string();
-                  score()->setNoteRest(segment(), track(), nval, data.duration, MScore::Direction::AUTO);
+                  score()->setNoteRest(segment(), track(), nval, duration(), MScore::Direction::AUTO);
                   delete e;
                   }
                   break;
