@@ -67,7 +67,7 @@ Image::Image(const Image& img)
       if (imageType == ImageType::RASTER)
             rasterDoc = img.rasterDoc ? new QImage(*img.rasterDoc) : 0;
       else if (imageType == ImageType::SVG)
-            svgDoc = img.svgDoc ? new QSvgRenderer(img.svgDoc) : 0;
+            svgDoc = img.svgDoc ? new QSvgRenderer(_storeItem->buffer()) : 0;
       setZ(img.z());
       }
 
@@ -265,8 +265,8 @@ void Image::draw(QPainter* painter) const
                         s = _size * spatium();
                   else
                         s = _size * DPMM;
-                  if (score()->printing()) {
-                        // use original image size for printing
+                  if (score()->printing() && !MScore::svgPrinting) {
+                        // use original image size for printing, but not for svg for reasonable file size.
                         painter->scale(s.width() / rasterDoc->width(), s.height() / rasterDoc->height());
                         painter->drawPixmap(QPointF(0, 0), QPixmap::fromImage(*rasterDoc));
                         }
