@@ -52,6 +52,19 @@ static InstrumentGroup* searchInstrumentGroup(const QString& name)
       return nullptr;
       }
 
+//---------------------------------------------------------
+//   searchArticulation
+//---------------------------------------------------------
+
+static MidiArticulation searchArticulation(const QString& name)
+      {
+      foreach(MidiArticulation a, articulation) {
+            if (a.name == name)
+                  return a;
+            }
+      return MidiArticulation();
+      }
+
 //---------------------------------------------------------
 //   readStaffIdx
 //---------------------------------------------------------
@@ -67,7 +80,7 @@ static int readStaffIdx(XmlReader& e)
       }
 
 //---------------------------------------------------------
-//   readInstrumentGroup
+//   read InstrumentGroup
 //---------------------------------------------------------
 
 void InstrumentGroup::read(XmlReader& e)
@@ -108,6 +121,16 @@ void InstrumentGroup::read(XmlReader& e)
             id = name.toLower().replace(" ", "-");
       }
 
+//---------------------------------------------------------
+//   clear InstrumentGroup
+//---------------------------------------------------------
+
+void InstrumentGroup::clear()
+      {
+      qDeleteAll(instrumentTemplates);
+      instrumentTemplates.clear();
+      }
+
 //---------------------------------------------------------
 //   InstrumentTemplate
 //---------------------------------------------------------
@@ -309,7 +332,7 @@ void InstrumentTemplate::write1(Xml& xml) const
 void InstrumentTemplate::read(XmlReader& e)
       {
       id = e.attribute("id");
-
+      int drumsetIndex = 0;
       while (e.readNextStartElement()) {
             const QStringRef& tag(e.name());
 
@@ -409,7 +432,8 @@ void InstrumentTemplate::read(XmlReader& e)
                         drumset = new Drumset(*smDrumset);
                         drumset->clear();
                         }
-                  drumset->load(e);
+                  drumset->load(e, drumsetIndex);
+                  drumsetIndex++;
                   }
             else if (tag == "MidiAction") {
                   NamedEventList a;
@@ -502,7 +526,7 @@ void InstrumentTemplate::read(XmlReader& e)
             channel.append(a);
             }
       if (useDrumset) {
-            if (channel[0].bank == 0)
+            if (channel[0].bank == 0 && channel[0].synti.toLower() != "zerberus")
                   channel[0].bank = 128;
             channel[0].updateInitList();
             }
@@ -602,6 +626,21 @@ bool saveInstrumentTemplates1(const QString& instrTemplates)
       return true;
       }
 
+//---------------------------------------------------------
+//   clearInstrumentTemplates
+//---------------------------------------------------------
+
+void clearInstrumentTemplates()
+      {
+      for (InstrumentGroup* g : instrumentGroups)
+            g->clear();
+      qDeleteAll(instrumentGroups);
+      instrumentGroups.clear();
+      qDeleteAll(instrumentGenres);
+      instrumentGenres.clear();
+      articulation.clear();
+      }
+
 //---------------------------------------------------------
 //   loadInstrumentTemplates
 //---------------------------------------------------------
@@ -620,8 +659,8 @@ bool loadInstrumentTemplates(const QString& instrTemplates)
                   while (e.readNextStartElement()) {
                         const QStringRef& tag(e.name());
                         if (tag == "instrument-group" || tag == "InstrumentGroup") {
-                              QString id(e.attribute("id"));
-                              InstrumentGroup* group = searchInstrumentGroup(id);
+                              QString idGroup(e.attribute("id"));
+                              InstrumentGroup* group = searchInstrumentGroup(idGroup);
                               if (group == 0) {
                                     group = new InstrumentGroup;
                                     instrumentGroups.append(group);
@@ -630,13 +669,14 @@ bool loadInstrumentTemplates(const QString& instrTemplates)
                               }
                         else if (tag == "Articulation") {
                               // read global articulation
-                              MidiArticulation a;
+                              QString name(e.attribute("name"));
+                              MidiArticulation a = searchArticulation(name);
                               a.read(e);
                               articulation.append(a);
                               }
                         else if (tag == "Genre") {
-                              QString id(e.attribute("id"));
-                              InstrumentGenre* genre = searchInstrumentGenre(id);
+                              QString idGenre(e.attribute("id"));
+                              InstrumentGenre* genre = searchInstrumentGenre(idGenre);
                               if (!genre) {
                                     genre = new InstrumentGenre;
                                     instrumentGenres.append(genre);
