@@ -70,6 +70,7 @@ class NoteHead : public Symbol {
             HEAD_TI,
             HEAD_SOL,
             HEAD_BREVIS_ALT,
+            HEAD_CUSTOM,
             HEAD_GROUPS,
             HEAD_INVALID = -1
             };
@@ -92,6 +93,8 @@ class NoteHead : public Symbol {
       Group headGroup() const;
 
       static const char* groupToGroupName(Group group);
+      static const char* type2name(Type type);
+      static Type name2type(const QString&);
       };
 
 //---------------------------------------------------------
@@ -236,7 +239,9 @@ class Note : public Element {
       NoteEventList _playEvents;
       QVector<Spanner*> _spannerFor;
       QVector<Spanner*> _spannerBack;
-
+      
+      SymId _cachedNoteheadSym; // use in draw to avoid recomputing at every update
+      
       virtual QRectF drag(EditData*) override;
       void endDrag();
       void endEdit();
@@ -260,6 +265,8 @@ class Note : public Element {
       QPointF canvasPos() const;    ///< position in page coordinates
       void layout();
       void layout2();
+      //setter is used only in drumset tools to setup the notehead preview in the drumset editor and the palette
+      void setCachedNoteheadSym(SymId i) { _cachedNoteheadSym = i; };
       void scanElements(void* data, void (*func)(void*, Element*), bool all=true);
       void setTrack(int val);
 
@@ -271,6 +278,10 @@ class Note : public Element {
       qreal tabHeadHeight(StaffType* tab = 0) const;
       QPointF stemDownNW() const;
       QPointF stemUpSE() const;
+      qreal bboxXShift() const;
+      qreal noteheadCenterX() const;
+      qreal bboxRightPos() const;
+      qreal headBodyWidth() const;
 
       SymId noteHead() const;
       NoteHead::Group headGroup() const   { return _headGroup; }
@@ -348,6 +359,8 @@ class Note : public Element {
       Note* firstTiedNote() const;
       Note* lastTiedNote() const;
       QList<Note*> tiedNotes() const;
+      void disconnectTiedNotes();
+      void connectTiedNotes();
 
       Chord* chord() const            { return (Chord*)parent(); }
       void setChord(Chord* a)         { setParent((Element*)a);  }
@@ -441,6 +454,7 @@ class Note : public Element {
       void setDotY(MScore::Direction);
 
       void addBracket();
+      bool isBefore(Note*);
 
       static SymId noteHead(int direction, NoteHead::Group, NoteHead::Type);
       NoteVal noteVal() const;
