@@ -57,7 +57,7 @@ static const PropertyData propertyList[] = {
       { P_ID::VELO_OFFSET,         false, "velocity",      P_TYPE::INT },
       { P_ID::ARTICULATION_ANCHOR, false, "anchor",        P_TYPE::INT },
       { P_ID::DIRECTION,           false, "direction",     P_TYPE::DIRECTION },
-      { P_ID::STEM_DIRECTION,      true,  "StemDirection", P_TYPE::DIRECTION },
+      { P_ID::STEM_DIRECTION,      false, "StemDirection", P_TYPE::DIRECTION },
 
       { P_ID::NO_STEM,             false, "noStem",        P_TYPE::INT },
       { P_ID::SLUR_DIRECTION,      false, "slurDirection", P_TYPE::INT },
@@ -237,6 +237,7 @@ static const PropertyData propertyList[] = {
       { P_ID::FRET_FRETS,          false, "frets",                 P_TYPE::INT },
       { P_ID::FRET_BARRE,          false, "barre",                 P_TYPE::INT },
       { P_ID::FRET_OFFSET,         false, "fretOffset",            P_TYPE::INT },
+      { P_ID::PLAY_REPEATS,        false, "playRepeats",           P_TYPE::BOOL},
 
       { P_ID::END,                 false, "",                      P_TYPE::INT }
       };
