@@ -158,14 +158,17 @@ void Score::updateChannel()
 //---------------------------------------------------------
 
 static void playNote(EventMap* events, const Note* note, int channel, int pitch,
-   int velo, int onTime, int offTime)
+   int velo, int onTime, int offTime, int staffIdx)
       {
       if (!note->play())
             return;
       velo = note->customizeVelocity(velo);
       NPlayEvent ev(ME_NOTEON, channel, pitch, velo);
+      ev.setOriginatingStaff(staffIdx);
       ev.setTuning(note->tuning());
       ev.setNote(note);
+      if (offTime < onTime)
+            offTime = onTime;
       events->insert(std::pair<int, NPlayEvent>(onTime, ev));
       ev.setVelo(0);
       events->insert(std::pair<int, NPlayEvent>(offTime, ev));
@@ -175,7 +178,7 @@ static void playNote(EventMap* events, const Note* note, int channel, int pitch,
 //   collectNote
 //---------------------------------------------------------
 
-static void collectNote(EventMap* events, int channel, const Note* note, int velo, int tickOffset)
+static void collectNote(EventMap* events, int channel, const Note* note, int velo, int tickOffset, int staffIdx)
       {
       if (!note->play() || note->hidden())      // do not play overlapping notes
             return;
@@ -208,7 +211,7 @@ static void collectNote(EventMap* events, int channel, const Note* note, int vel
                               }
                         else {
                               // recurse
-                              collectNote(events, channel, n, velo, tickOffset);
+                              collectNote(events, channel, n, velo, tickOffset, staffIdx);
                               break;
                               }
                         if (n->tieFor() && n != n->tieFor()->endNote())
@@ -227,7 +230,7 @@ static void collectNote(EventMap* events, int channel, const Note* note, int vel
       int nels = nel.size();
       for (int i = 0; i < nels; ++i) {
             const NoteEvent& e = nel[i]; // we make an explict const ref, not a const copy.  no need to copy as we won't change the original object.
-          
+
             // skip if note has a tie into it and only one NoteEvent
             // its length was already added to previous note
             // if we wish to suppress first note of ornament
@@ -243,7 +246,7 @@ static void collectNote(EventMap* events, int channel, const Note* note, int vel
             int off = on + (ticks * e.len())/1000 - 1;
             if (tieFor && i == nels - 1)
                   off += tieLen;
-            playNote(events, note, channel, p, velo, on, off);
+            playNote(events, note, channel, p, velo, on, off, staffIdx);
             }
 
       // Bends
@@ -269,6 +272,7 @@ static void collectNote(EventMap* events, int channel, const Note* note, int vel
                         int msb = midiPitch / 128;
                         int lsb = midiPitch % 128;
                         NPlayEvent ev(ME_PITCHBEND, channel, lsb, msb);
+                        ev.setOriginatingStaff(staffIdx);
                         events->insert(std::pair<int, NPlayEvent>(lastPointTick, ev));
                         lastPointTick = nextPointTick;
                         continue;
@@ -296,11 +300,13 @@ static void collectNote(EventMap* events, int channel, const Note* note, int vel
                         int msb = midiPitch / 128;
                         int lsb = midiPitch % 128;
                         NPlayEvent ev(ME_PITCHBEND, channel, lsb, msb);
+                        ev.setOriginatingStaff(staffIdx);
                         events->insert(std::pair<int, NPlayEvent>(i, ev));
                         }
                   lastPointTick = nextPointTick;
                   }
             NPlayEvent ev(ME_PITCHBEND, channel, 0, 64); // 0:64 is 8192 - no pitch bend
+            ev.setOriginatingStaff(staffIdx);
             events->insert(std::pair<int, NPlayEvent>(tick1+noteLen, ev));
             }
       }
@@ -355,9 +361,11 @@ static void collectMeasureEvents(EventMap* events, Measure* m, Staff* staff, int
 
                   Chord* chord = static_cast<Chord*>(cr);
                   Staff* staff = chord->staff();
+                  int staffIdx = staff->idx();
                   int velocity = staff->velocities().velo(seg->tick());
                   Instrument* instr = chord->part()->instrument(tick);
                   int channel = instr->channel(chord->upNote()->subchannel())->channel;
+                  events->registerChannel(channel);
 
                   foreach (Articulation* a, chord->articulations()) {
                         instr->updateVelocity(&velocity,channel, a->subtypeName());
@@ -365,11 +373,11 @@ static void collectMeasureEvents(EventMap* events, Measure* m, Staff* staff, int
 
                   for (Chord* c : chord->graceNotesBefore()) {
                         for (const Note* note : c->notes())
-                              collectNote(events, channel, note, velocity, tickOffset);
+                              collectNote(events, channel, note, velocity, tickOffset, staffIdx);
                         }
 
                   foreach (const Note* note, chord->notes())
-                        collectNote(events, channel, note, velocity, tickOffset);
+                        collectNote(events, channel, note, velocity, tickOffset, staffIdx);
 
 #if 0
                   // TODO: add support for grace notes after - see createPlayEvents()
@@ -377,7 +385,7 @@ static void collectMeasureEvents(EventMap* events, Measure* m, Staff* staff, int
                   chord->getGraceNotesAfter(&gna);
                   for (Chord* c : gna) {
                         for (const Note* note : c->notes())
-                              collectNote(events, channel, note, velocity, tickOffset);
+                              collectNote(events, channel, note, velocity, tickOffset, staffIdx);
                         }
 #endif
 
@@ -407,6 +415,7 @@ static void collectMeasureEvents(EventMap* events, Measure* m, Staff* staff, int
                               for (MidiCoreEvent event : nel->events) {
                                     event.setChannel(channel);
                                     NPlayEvent e(event);
+                                    e.setOriginatingStaff(firstStaffIdx);
                                     if (e.dataA() == CTRL_PROGRAM)
                                           events->insert(std::pair<int, NPlayEvent>(tick-1, e));
                                     else
@@ -439,15 +448,19 @@ void Score::updateRepeatList(bool expandRepeats)
             foreach(RepeatSegment* s, *repeatList())
                   delete s;
             repeatList()->clear();
-            Measure* m = lastMeasure();
+            Measure* m = firstMeasure();
             if (m == 0)
                   return;
             RepeatSegment* s = new RepeatSegment;
             s->tick  = 0;
-            s->len   = m->tick() + m->ticks();
             s->utick = 0;
             s->utime = 0.0;
             s->timeOffset = 0.0;
+            do {
+                  s->addMeasure(m);
+                  m = m->nextMeasure();
+                  }
+            while (m);
             repeatList()->append(s);
             }
       else
@@ -618,7 +631,7 @@ void Score::renderStaff(EventMap* events, Staff* staff)
       Measure* lastMeasure = 0;
       foreach (const RepeatSegment* rs, *repeatList()) {
             int startTick  = rs->tick;
-            int endTick    = startTick + rs->len;
+            int endTick    = startTick + rs->len();
             int tickOffset = rs->utick - rs->tick;
             for (Measure* m = tick2measure(startTick); m; m = m->nextMeasure()) {
                   if (lastMeasure && m->isRepeatMeasure(staff)) {
@@ -639,43 +652,44 @@ void Score::renderStaff(EventMap* events, Staff* staff)
 //   renderSpanners
 //---------------------------------------------------------
 
-void Score::renderSpanners(EventMap* events, int staffIdx)
+void Score::renderSpanners(EventMap* events)
       {
       foreach (const RepeatSegment* rs, *repeatList()) {
             int tickOffset = rs->utick - rs->tick;
             int utick1 = rs->utick;
             int tick1 = repeatList()->utick2tick(utick1);
-            int tick2 = tick1 + rs->len;
-            std::map<int, std::vector<std::pair<int, bool>>> channelPedalEvents = std::map<int, std::vector<std::pair<int, bool>>>();
+            int tick2 = tick1 + rs->len();
+            std::map<int, std::vector<std::pair<int, std::pair<bool, int>>>> channelPedalEvents;
             for (const auto& sp : _spanner.map()) {
                   Spanner* s = sp.second;
-                  if (s->type() != Element::Type::PEDAL || (staffIdx != -1 && s->staffIdx() != staffIdx))
+                  if (s->type() != Element::Type::PEDAL)
                         continue;
 
+                  int staff = s->staffIdx();
                   int idx = s->staff()->channel(s->tick(), 0);
                   int channel = s->part()->instrument(s->tick())->channel(idx)->channel;
-                  channelPedalEvents.insert({channel, std::vector<std::pair<int, bool>>()});
-                  std::vector<std::pair<int, bool>> pedalEventList = channelPedalEvents.at(channel);
-                  std::pair<int, bool> lastEvent;
+                  channelPedalEvents.insert({channel, std::vector<std::pair<int, std::pair<bool, int>>>()});
+                  std::vector<std::pair<int, std::pair<bool, int>>> pedalEventList = channelPedalEvents.at(channel);
+                  std::pair<int, std::pair<bool, int>> lastEvent;
 
                   if (!pedalEventList.empty())
                         lastEvent = pedalEventList.back();
                   else
-                        lastEvent = std::pair<int, bool>(0, true);
+                        lastEvent = std::pair<int, std::pair<bool, int>>(0, std::pair<bool, int>(true, staff));
 
                   if (s->tick() >= tick1 && s->tick() < tick2) {
                         // Handle "overlapping" pedal segments (usual case for connected pedal line)
-                        if (lastEvent.second == false && lastEvent.first >= (s->tick() + tickOffset + 2)) {
+                        if (lastEvent.second.first == false && lastEvent.first >= (s->tick() + tickOffset + 2)) {
                               channelPedalEvents.at(channel).pop_back();
-                              channelPedalEvents.at(channel).push_back(std::pair<int, bool>(s->tick() + tickOffset + 1, false));
+                              channelPedalEvents.at(channel).push_back(std::pair<int, std::pair<bool, int>>(s->tick() + tickOffset + 1, std::pair<bool, int>(false, staff)));
                               }
-                        channelPedalEvents.at(channel).push_back(std::pair<int, bool>(s->tick() + tickOffset + 2, true));
+                        channelPedalEvents.at(channel).push_back(std::pair<int, std::pair<bool, int>>(s->tick() + tickOffset + 2, std::pair<bool, int>(true, staff)));
                         }
                   if (s->tick2() >= tick1 && s->tick2() <= tick2) {
                         int t = s->tick2() + tickOffset + 1;
-                        if (t > repeatList()->last()->utick + repeatList()->last()->len)
-                              t = repeatList()->last()->utick + repeatList()->last()->len;
-                        channelPedalEvents.at(channel).push_back(std::pair<int, bool>(t, false));
+                        if (t > repeatList()->last()->utick + repeatList()->last()->len())
+                              t = repeatList()->last()->utick + repeatList()->last()->len();
+                        channelPedalEvents.at(channel).push_back(std::pair<int, std::pair<bool, int>>(t, std::pair<bool, int>(false, staff)));
                         }
                   }
 
@@ -683,10 +697,11 @@ void Score::renderSpanners(EventMap* events, int staffIdx)
                   int channel = pedalEvents.first;
                   for (const auto& pe : pedalEvents.second) {
                         NPlayEvent event;
-                        if (pe.second == true)
+                        if (pe.second.first == true)
                               event = NPlayEvent(ME_CONTROLLER, channel, CTRL_SUSTAIN, 127);
                         else
                               event = NPlayEvent(ME_CONTROLLER, channel, CTRL_SUSTAIN, 0);
+                        event.setOriginatingStaff(pe.second.second);
                         events->insert(std::pair<int,NPlayEvent>(pe.first, event));
                         }
                   }
@@ -746,17 +761,40 @@ bool Score::isSubdivided(ChordRest* chord, int swingUnit)
             return false;
       }
 
+const Drumset* getDrumset(const Chord* chord)
+      {
+      if (chord->staff() && chord->staff()->isDrumStaff()) {
+            const Drumset* ds = chord->staff()->part()->instrument(chord->tick())->drumset();
+            return ds;
+            }
+      return nullptr;
+      }
+
 //---------------------------------------------------------
 //   renderTremolo
 //---------------------------------------------------------
 
-void renderTremolo(Chord *chord, QList<NoteEventList> & ell)
+void renderTremolo(Chord* chord, QList<NoteEventList>& ell)
       {
       Segment* seg = chord->segment();
       Tremolo* tremolo = chord->tremolo();
       int notes = chord->notes().size();
-      //int n = 1 << tremolo->lines();
-      //int l = 1000 / n;
+
+      // check if tremolo was rendered before for drum staff
+      const Drumset* ds = getDrumset(chord);
+      if (ds) {
+            for (Note* n : chord->notes()) {
+                  DrumInstrumentVariant div = ds->findVariant(n->pitch(), chord->articulations(), chord->tremolo());
+                  if (div.pitch != INVALID_PITCH && div.tremolo == tremolo->tremoloType())
+                        return; // already rendered
+                  }
+            }
+
+      // we cannot render buzz roll with MIDI events only
+      if (tremolo->tremoloType() == TremoloType::BUZZ_ROLL)
+            return;
+
+      // render tremolo with multiple events
       if (chord->tremoloChordType() == TremoloChordType::TremoloFirstNote) {
             int t = MScore::division / (1 << (tremolo->lines() + chord->durationType().hooks()));
             Segment::Type st = Segment::Type::ChordRest;
@@ -841,7 +879,7 @@ void renderArpeggio(Chord *chord, QList<NoteEventList> & ell)
       {
       int notes = chord->notes().size();
       int l = 64;
-      while (l * notes > chord->upNote()->playTicks())
+      while (l && (l * notes > chord->upNote()->playTicks()))
             l = 2*l / 3;
       int start, end, step;
       bool up = chord->arpeggio()->arpeggioType() != ArpeggioType::DOWN && chord->arpeggio()->arpeggioType() != ArpeggioType::DOWN_STRAIGHT;
@@ -933,7 +971,7 @@ int articulationExcursion(Note *noteL, Note *noteR, int deltastep)
       int endTrack   = startTrack + VOICES;
       bool done = false;
       for (int track = startTrack; track < endTrack; ++track) {
-            Element *e = segment->element(track);
+            Element* e = segment->element(track);
             if (!e || e->type() != Element::Type::CHORD)
                   continue;
             Chord* chord = static_cast<Chord*>(e);
@@ -995,7 +1033,7 @@ int totalTiedNoteTicks(Note* note)
 bool renderNoteArticulation(NoteEventList* events, Note * note, bool chromatic, int requestedTicksPerNote,
    const vector<int> & prefix, const vector<int> & body,
    bool repeatp, bool sustainp, const vector<int> & suffix,
-   int fastestFreq=16, int slowestFreq=8 // 16 Hz and 8 Hz
+   int fastestFreq=64, int slowestFreq=8 // 16 Hz and 8 Hz
    )
       {
 
@@ -1402,7 +1440,16 @@ static QList<NoteEventList> renderChord(Chord* chord, int gateTime, int ontime)
 void Score::createGraceNotesPlayEvents(QList<Chord*> gnb, int tick, Chord* chord, int &ontime)
       {
       int n = gnb.size();
-      if (n) {
+      int graceDuration = 0;
+      bool drumset = (getDrumset(chord) != nullptr);
+      const qreal ticksPerSecond = tempo(tick) * MScore::division;
+      const qreal chordTimeMS = (chord->actualTicks() / ticksPerSecond) * 1000;
+      if (drumset) {
+            int flamDuration = 15; //ms
+            graceDuration = flamDuration / chordTimeMS * 1000; //ratio 1/1000 from the main note length
+            ontime = graceDuration * n;
+            }
+      else if (n) {
             //
             //  render grace notes:
             //  simplified implementation:
@@ -1414,11 +1461,8 @@ void Score::createGraceNotesPlayEvents(QList<Chord*> gnb, int tick, Chord* chord
             //
             Chord* graceChord = gnb[0];
             if (graceChord->noteType() ==  NoteType::ACCIACCATURA) {
-                  qreal ticksPerSecond = tempo(tick) * MScore::division;
                   int graceTimeMS = 65 * n;     // value determined empirically (TODO: make instrument-specific, like articulations)
-                  // 1000 occurs below for two different reasons:
-                  // number of milliseconds per second, also unit for ontime
-                  qreal chordTimeMS = (chord->actualTicks() / ticksPerSecond) * 1000;
+                  // 1000 occurs below as a unit for ontime
                   ontime = qMin(500, static_cast<int>((graceTimeMS / chordTimeMS) * 1000));
                   }
             else if (chord->dots() == 1)
@@ -1428,27 +1472,27 @@ void Score::createGraceNotesPlayEvents(QList<Chord*> gnb, int tick, Chord* chord
             else
                   ontime = 500;
 
-            int graceDuration = ontime / n;
+            graceDuration = ontime / n;
+            }
 
-            int on = 0;
-            for (int i = 0; i < n; ++i) {
-                  QList<NoteEventList> el;
-                  Chord* gc = gnb.at(i);
-                  int nn = gc->notes().size();
-                  for (int ii = 0; ii < nn; ++ii) {
-                        NoteEventList nel;
-                        nel.append(NoteEvent(0, on, graceDuration));
-                        el.append(nel);
-                        }
-
-                  if (gc->playEventType() == PlayEventType::InvalidUser)
-                        gc->score()->undo(new ChangeEventList(gc, el));
-                  else if (gc->playEventType() == PlayEventType::Auto) {
-                        for (int ii = 0; ii < nn; ++ii)
-                              gc->notes()[ii]->setPlayEvents(el[ii]);
-                        }
-                  on += graceDuration;
+      int on = 0;
+      for (int i = 0; i < n; ++i) {
+            QList<NoteEventList> el;
+            Chord* gc = gnb.at(i);
+            int nn = gc->notes().size();
+            for (int ii = 0; ii < nn; ++ii) {
+                  NoteEventList nel;
+                  nel.append(NoteEvent(0, on, graceDuration));
+                  el.append(nel);
                   }
+
+            if (gc->playEventType() == PlayEventType::InvalidUser)
+                  gc->score()->undo(new ChangeEventList(gc, el));
+            else if (gc->playEventType() == PlayEventType::Auto) {
+                  for (int ii = 0; ii < nn; ++ii)
+                        gc->notes()[ii]->setPlayEvents(el[ii]);
+                  }
+            on += graceDuration;
             }
       }
 
@@ -1514,9 +1558,10 @@ void Score::createPlayEvents()
                         continue;
                   const Segment::Type st = Segment::Type::ChordRest;
                   for (Segment* seg = m->first(st); seg; seg = seg->next(st)) {
-                        Chord* chord = static_cast<Chord*>(seg->element(track));
-                        if (chord == 0 || chord->type() != Element::Type::CHORD)
+                        Element* el = seg->element(track);
+                        if (el == 0 || el->type() != Element::Type::CHORD)
                               continue;
+                        Chord* chord = static_cast<Chord*>(el);
                         createPlayEvents(chord);
                         }
                   }
@@ -1557,26 +1602,33 @@ void Score::renderMetronome(EventMap* events, Measure* m, int tickOffset)
 //---------------------------------------------------------
 
 void Score::renderMidi(EventMap* events)
+      {
+      renderMidi(events, true, MScore::playRepeats);
+      }
+
+void Score::renderMidi(EventMap* events, bool metronome, bool expandRepeats)
       {
       updateSwing();
       createPlayEvents();
 
-      updateRepeatList(MScore::playRepeats);
-      _foundPlayPosAfterRepeats = false;
+      updateRepeatList(expandRepeats);
       updateChannel();
       updateVelo();
 
       // create note & other events
       foreach (Staff* part, _staves)
             renderStaff(events, part);
+      events->fixupMIDI();
 
       // create sustain pedal events
-      renderSpanners(events, -1);
+      renderSpanners(events);
 
+      if (!metronome)
+            return;
       // add metronome ticks
       foreach (const RepeatSegment* rs, *repeatList()) {
             int startTick  = rs->tick;
-            int endTick    = startTick + rs->len;
+            int endTick    = startTick + rs->len();
             int tickOffset = rs->utick - rs->tick;
 
             //
