@@ -209,7 +209,6 @@ bool Rest::acceptDrop(const DropData& data) const
          || (type == Element::Type::DYNAMIC)
          || (type == Element::Type::HARMONY)
          || (type == Element::Type::TEMPO_TEXT)
-         || (type == Element::Type::STAFF_TEXT)
          || (type == Element::Type::REHEARSAL_MARK)
          || (type == Element::Type::FRET_DIAGRAM)
          || (type == Element::Type::TREMOLOBAR)
@@ -296,7 +295,7 @@ SymId Rest::getSymbol(TDuration::DurationType type, int line, int lines, int* yo
             case TDuration::DurationType::V_MEASURE:
                   if (duration() >= Fraction(2, 1))
                         return SymId::restDoubleWhole;
-                  // fall trough
+                  // fall through
             case TDuration::DurationType::V_WHOLE:
                   *yoffset = 1;
                   return (line <= -2 || line >= (lines - 1)) ? SymId::restWholeLegerLine : SymId::restWhole;
@@ -321,7 +320,7 @@ SymId Rest::getSymbol(TDuration::DurationType type, int line, int lines, int* yo
             case TDuration::DurationType::V_1024TH:
                   return SymId::rest1024th;
             default:
-                  qDebug("unknown rest type %hhd", type);
+                  qDebug("unknown rest type %d", int(type));
                   return SymId::restQuarter;
             }
       }
