@@ -960,6 +960,19 @@ bool Segment::findAnnotationOrElement(Element::Type type, int minTrack, int maxT
       return false;
       }
 
+//---------------------------------------------------------
+//   findAnnotation
+///  return true if an annotation of type type
+//---------------------------------------------------------
+
+bool Segment::findAnnotation(Element::Type type, int minTrack, int maxTrack)
+      {
+      for (const Element* e : _annotations)
+            if (e->type() == type && e->track() >= minTrack && e->track() <= maxTrack)
+                  return true;
+      return false;
+      }
+
 //---------------------------------------------------------
 //   removeAnnotation
 //---------------------------------------------------------
