@@ -24,6 +24,7 @@
 #include "figuredbass.h"
 #include "glissando.h"
 #include "harmony.h"
+#include "fret.h"
 #include "hook.h"
 #include "input.h"
 #include "limits.h"
@@ -501,6 +502,8 @@ void Selection::updateSelectedElements()
             // ignore spanners belonging to other tracks
             if (sp->track() < startTrack || sp->track() >= endTrack)
                   continue;
+            if (!canSelectVoice(sp->track()))
+                  continue;
             // ignore voltas
             if (sp->type() == Element::Type::VOLTA)
                   continue;
@@ -780,7 +783,6 @@ Enabling copying of more element types requires enabling pasting in Score::paste
                   case Element::Type::STAFF_TEXT:
                   case Element::Type::REHEARSAL_MARK:
                   case Element::Type::INSTRUMENT_CHANGE:
-                  case Element::Type::FRET_DIAGRAM:
                   case Element::Type::BEND:
                   case Element::Type::TREMOLOBAR:
                   case Element::Type::VOLTA:
@@ -853,6 +855,13 @@ Enabling copying of more element types requires enabling pasting in Score::paste
                               break;
                               }
                         continue;
+                  case Element::Type::FRET_DIAGRAM:
+                        // ignore fret diagrams not attached to segment
+                        if (e->parent()->type() == Element::Type::SEGMENT) {
+                              seg = static_cast<Segment*>( (static_cast<FretDiagram*>(e))->parent() );
+                              break;
+                              }
+                        continue;
                   case Element::Type::LYRICS:
                         seg = (static_cast<Lyrics*>(e))->segment();
                         break;
