@@ -2663,8 +2663,8 @@ class ScoreFont {
       void draw(const QList<SymId>&, QPainter*, qreal mag, const QPointF& pos, qreal scale) const;
       void draw(SymId id, QPainter* painter, qreal mag, const QPointF& pos, int n) const;
 
-      qreal height(SymId id, qreal mag) const         { return sym(id).bbox().height() * mag; }
-      qreal width(SymId id, qreal mag) const          { return sym(id).bbox().width() * mag;  }
+      qreal height(SymId id, qreal mag) const         { return bbox(id, mag).height(); }
+      qreal width(SymId id, qreal mag) const          { return bbox(id, mag).width();  }
       qreal advance(SymId id, qreal mag) const        { return sym(id).advance() * mag;  }
       qreal width(const QList<SymId>&, qreal mag) const;
 
@@ -2678,6 +2678,7 @@ class ScoreFont {
       QPointF cutOutSW(SymId id, qreal mag) const     { return sym(id).cutOutSW() * mag; }
 
       bool isValid(SymId id) const                    { return sym(id).isValid(); }
+      bool useFallbackFont(SymId id) const;
       };
 
 extern void initScoreFonts();
