@@ -231,6 +231,30 @@ bool XmlReader::readBool()
       return val;
       }
 
+//---------------------------------------------------------
+//   checkTuplets
+//---------------------------------------------------------
+
+void XmlReader::checkTuplets()
+      {
+      for (Tuplet* tuplet : tuplets()) {
+            if (tuplet->elements().empty()) {
+                  // this should not happen and is a sign of input file corruption
+                  qDebug("Measure:read(): empty tuplet id %d (%p), input file corrupted?",
+                     tuplet->id(), tuplet);
+                  delete tuplet;
+                  }
+            else {
+                  //sort tuplet elements. Needed for nested tuplets #22537
+                  tuplet->sortElements();
+                  tuplet->sanitizeTuplet();
+                  }
+            }
+      // This requires a separate pass in case of nested tuplets that required sanitizing
+      for (Tuplet* tuplet : tuplets())
+            tuplet->addMissingElements();
+      }
+
 //---------------------------------------------------------
 //   compareProperty
 //---------------------------------------------------------
