@@ -51,7 +51,8 @@ InstrumentsDialog::InstrumentsDialog(QWidget* parent)
       QAction* a = getAction("instruments");
       connect(a, SIGNAL(triggered()), SLOT(reject()));
       addAction(a);
-
+      saveButton->setVisible(false);
+      loadButton->setVisible(false);
       readSettings();
       }
 
@@ -172,6 +173,24 @@ QTreeWidget* InstrumentsDialog::partiturList()
       }
 
 //---------------------------------------------------------
+//   buildInstrumentsList
+//---------------------------------------------------------
+
+void InstrumentsDialog::buildInstrumentsList()
+      {
+      instrumentsWidget->buildTemplateList();
+      }
+
+//---------------------------------------------------------
+//   updateInstrumentDialog
+//---------------------------------------------------------
+
+void MuseScore::updateInstrumentDialog()
+      {
+      if (instrList)
+            instrList->buildInstrumentsList();
+      }
+//---------------------------------------------------------
 //   editInstrList
 //---------------------------------------------------------
 
