@@ -24,6 +24,7 @@
 #include "palette.h"
 #include "instrdialog.h"
 #include "scoreBrowser.h"
+#include "extension.h"
 
 #include "libmscore/instrtemplate.h"
 #include "libmscore/score.h"
@@ -230,6 +231,15 @@ void NewWizardPage2::createInstruments(Score* s)
       w->createInstruments(s);
       }
 
+//---------------------------------------------------------
+//   buildInstrumentsList
+//---------------------------------------------------------
+
+void NewWizardPage2::buildInstrumentsList()
+      {
+      w->buildTemplateList();
+      }
+
 //---------------------------------------------------------
 //   NewWizardPage3
 //---------------------------------------------------------
@@ -262,18 +272,9 @@ NewWizardPage4::NewWizardPage4(QWidget* parent)
 
       templateFileBrowser = new ScoreBrowser;
       templateFileBrowser->setStripNumbers(true);
-      QDir dir(mscoreGlobalShare + "/templates");
-      QFileInfoList fil = dir.entryInfoList(QDir::NoDotAndDotDot | QDir::Readable | QDir::Dirs | QDir::Files, QDir::Name);
-      if(fil.isEmpty()){
-          fil.append(QFileInfo(QFile(":data/Empty_Score.mscz")));
-          }
-
-      QDir myTemplatesDir(preferences.myTemplatesPath);
-      fil.append(myTemplatesDir.entryInfoList(QDir::NoDotAndDotDot | QDir::Readable | QDir::Dirs | QDir::Files, QDir::Name));
-
       templateFileBrowser->setShowCustomCategory(true);
-      templateFileBrowser->setScores(fil);
       templateFileBrowser->setSizePolicy(QSizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored));
+      buildTemplatesList();
 
       QVBoxLayout* layout = new QVBoxLayout;
       QHBoxLayout* searchLayout = new QHBoxLayout;
@@ -305,6 +306,30 @@ void NewWizardPage4::initializePage()
       path.clear();
       }
 
+//---------------------------------------------------------
+//   buildTemplatesList
+//---------------------------------------------------------
+
+void NewWizardPage4::buildTemplatesList()
+      {
+      QDir dir(mscoreGlobalShare + "/templates");
+      QFileInfoList fil = dir.entryInfoList(QDir::NoDotAndDotDot | QDir::Readable | QDir::Dirs | QDir::Files, QDir::Name);
+      if(fil.isEmpty()){
+          fil.append(QFileInfo(QFile(":data/Empty_Score.mscz")));
+          }
+
+      QDir myTemplatesDir(preferences.myTemplatesPath);
+      fil.append(myTemplatesDir.entryInfoList(QDir::NoDotAndDotDot | QDir::Readable | QDir::Dirs | QDir::Files, QDir::Name));
+
+      // append templates directories from extensions
+      QStringList extensionsDir = Extension::getDirectoriesByType(Extension::templatesDir);
+      for (QString extDir : extensionsDir) {
+            QDir extTemplateDir(extDir);
+            fil.append(extTemplateDir.entryInfoList(QDir::NoDotAndDotDot | QDir::Readable | QDir::Dirs | QDir::Files, QDir::Name));
+            }
+      templateFileBrowser->setScores(fil);
+      }
+
 //---------------------------------------------------------
 //   isComplete
 //---------------------------------------------------------
@@ -377,7 +402,7 @@ NewWizardPage5::NewWizardPage5(QWidget* parent)
       _tempo = new QDoubleSpinBox;
       _tempo->setAccessibleName(tr("Beats per minute"));
       _tempo->setRange(20.0, 400.0);
-      _tempo->setValue(100.0);
+      _tempo->setValue(120.0);
       _tempo->setDecimals(1);
       QHBoxLayout* l2 = new QHBoxLayout;
       l2->addWidget(bpm);
@@ -478,6 +503,16 @@ bool NewWizard::emptyScore() const
       return fi.completeBaseName() == "00-Blank";
       }
 
+//---------------------------------------------------------
+//   updateValues
+//---------------------------------------------------------
+
+void NewWizard::updateValues() const
+      {
+      p2->buildInstrumentsList();
+      p4->buildTemplatesList();
+      }
+
 //---------------------------------------------------------
 //   hideEvent
 //---------------------------------------------------------
