@@ -361,6 +361,10 @@ void Palette::mouseDoubleClickEvent(QMouseEvent* ev)
                   else
                         qDebug("nowhere to place drum note");
                   }
+            else if (element->type() == Element::Type::LAYOUT_BREAK) {
+                  LayoutBreak* breakElement = static_cast<LayoutBreak*>(element);
+                  score->cmdToggleLayoutBreak(breakElement->layoutBreakType());
+                  }
             else if (element->type() == Element::Type::SLUR && addSingle) {
                   viewer->cmdAddSlur();
                   }
@@ -385,7 +389,6 @@ void Palette::mouseDoubleClickEvent(QMouseEvent* ev)
                 || element->type() == Element::Type::MARKER
                 || element->type() == Element::Type::JUMP
                 || element->type() == Element::Type::SPACER
-                || element->type() == Element::Type::LAYOUT_BREAK
                 || element->type() == Element::Type::VBOX
                 || element->type() == Element::Type::HBOX
                 || element->type() == Element::Type::TBOX
@@ -407,6 +410,10 @@ void Palette::mouseDoubleClickEvent(QMouseEvent* ev)
                               break;
                         }
                   }
+            else if (element->type() == Element::Type::LAYOUT_BREAK) {
+                  LayoutBreak* breakElement = static_cast<LayoutBreak*>(element);
+                  score->cmdToggleLayoutBreak(breakElement->layoutBreakType());
+                  }
             else if (element->type() == Element::Type::CLEF
                      || element->type() == Element::Type::KEYSIG
                      || element->type() == Element::Type::TIMESIG) {
@@ -513,6 +520,7 @@ void Palette::mouseDoubleClickEvent(QMouseEvent* ev)
                   for (int i = sel.staffStart(); i < endStaff; ++i) {
                         Spanner* spanner = static_cast<Spanner*>(element->clone());
                         spanner->setScore(score);
+                        spanner->styleChanged();
                         score->cmdAddSpanner(spanner, i, startSegment, endSegment);
                         }
                   }
@@ -524,7 +532,7 @@ void Palette::mouseDoubleClickEvent(QMouseEvent* ev)
                   for (Segment* s = startSegment; s && s != endSegment; s = s->next1()) {
                         for (int track = track1; track < track2; ++track) {
                               Element* e = s->element(track);
-                              if (e == 0)
+                              if (e == 0 || !score->selectionFilter().canSelect(e) || !score->selectionFilter().canSelectVoice(track))
                                     continue;
                               if (e->type() == Element::Type::CHORD) {
                                     Chord* chord = static_cast<Chord*>(e);
