@@ -63,6 +63,7 @@ PluginCreator::PluginCreator(QWidget* parent)
 
       actionSave->setIcon(*icons[int(Icons::fileSave_ICON)]);
       actionSave->setShortcut(QKeySequence(QKeySequence::Save));
+      actionSaveAs->setIcon(*icons[int(Icons::fileSaveAs_ICON)]);
       fileTools->addAction(actionSave);
 
       actionQuit->setShortcut(QKeySequence(QKeySequence::Close));
@@ -99,6 +100,7 @@ PluginCreator::PluginCreator(QWidget* parent)
       connect(actionOpen, SIGNAL(triggered()),   SLOT(loadPlugin()));
       connect(actionReload, SIGNAL(triggered()), SLOT(load()));
       connect(actionSave, SIGNAL(triggered()),   SLOT(savePlugin()));
+      connect(actionSaveAs, SIGNAL(triggered()), SLOT(savePluginAs()));
       connect(actionNew,  SIGNAL(triggered()),   SLOT(newPlugin()));
       connect(actionQuit, SIGNAL(triggered()),   SLOT(close()));
       connect(actionManual, SIGNAL(triggered()), SLOT(showManual()));
@@ -136,6 +138,7 @@ void PluginCreator::setState(PCState newState)
                         case PCState::EMPTY:
                               setTitle("");
                               actionSave->setEnabled(false);
+                              actionSaveAs->setEnabled(false);
                               run->setEnabled(false);
                               stop->setEnabled(false);
                               textEdit->setEnabled(false);
@@ -152,6 +155,7 @@ void PluginCreator::setState(PCState newState)
                               break;
                         case PCState::CLEAN:
                               setTitle(path);
+                              actionSaveAs->setEnabled(true);
                               run->setEnabled(true);
                               textEdit->setEnabled(true);
                               break;
@@ -167,6 +171,7 @@ void PluginCreator::setState(PCState newState)
                               break;
                         case PCState::DIRTY:
                               actionSave->setEnabled(true);
+                              actionSaveAs->setEnabled(true);
                               break;
                         }
                   break;
@@ -176,6 +181,7 @@ void PluginCreator::setState(PCState newState)
                         case PCState::EMPTY:
                         case PCState::CLEAN:
                               actionSave->setEnabled(false);
+                              actionSave->setEnabled(true);
                         case PCState::DIRTY:
                               break;
                         }
@@ -256,7 +262,7 @@ void PluginCreator::closeEvent(QCloseEvent* ev)
 //   qmlMsgHandler
 //---------------------------------------------------------
 
-static void qmlMsgHandler(QtMsgType type, const char* msg)
+static void qmlMsgHandler(QtMsgType type, const QMessageLogContext &, const QString & msg)
       {
       QString s;
       switch(type) {
@@ -273,9 +279,6 @@ static void qmlMsgHandler(QtMsgType type, const char* msg)
                   s = QString("Fatal: %1\n").arg(msg);
                   break;
             default:
-
-// Qt5.2?   case QtTraceMsg:
-// Qt5.4   case QtInfoMsg:
                   s = QString("Info: %1\n").arg(msg);
                   break;
             }
@@ -289,6 +292,7 @@ static void qmlMsgHandler(QtMsgType type, const char* msg)
 void PluginCreator::runClicked()
       {
       log->clear();
+      msg(tr("Running...\n"));
       QQmlEngine* qml = Ms::MScore::qml();
       connect(qml, SIGNAL(warnings(const QList<QQmlError>&)),
          SLOT(qmlWarnings(const QList<QQmlError>&)));
@@ -298,17 +302,22 @@ void PluginCreator::runClicked()
       component.setData(textEdit->toPlainText().toUtf8(), QUrl());
       QObject* obj = component.create();
       if (obj == 0) {
-            msg("creating component failed\n");
+            msg(tr("creating component failed\n"));
             foreach(QQmlError e, component.errors())
                   msg(QString("   line %1: %2\n").arg(e.line()).arg(e.description()));
             stop->setEnabled(false);
             return;
             }
-      qInstallMsgHandler(qmlMsgHandler);
+      qInstallMessageHandler(qmlMsgHandler);
       stop->setEnabled(true);
       run->setEnabled(false);
 
       item = qobject_cast<QmlPlugin*>(obj);
+      msg(tr("Plugin Details:") + "\n");
+      msg("  " + tr("Menu Path:") + " " + item->menuPath() + "\n");
+      msg("  " + tr("Version:") + " " + item->version() + "\n");
+      msg("  " + tr("Description:") + " " + item->description() + "\n");
+
       item->setFilePath(path.isEmpty() ? QString() : path.section('/', 0, -2));
 
       if (item->pluginType() == "dock" || item->pluginType() == "dialog") {
@@ -338,7 +347,6 @@ void PluginCreator::runClicked()
                   dock->show();
                   }
             view->show();
-            view->raise();
             connect(view, SIGNAL(destroyed()), SLOT(closePlugin()));
             }
 
@@ -350,6 +358,16 @@ void PluginCreator::runClicked()
       if (mscore->currentScore() && item->pluginType() != "dock")
             mscore->currentScore()->endCmd();
       mscore->endCmd();
+      // Main window is on top at this point. Make sure correct view is on top.
+      if (item->pluginType() == "dock") {
+            raise(); // Screen needs to be on top to see docked panel.
+            }
+      else if (view) {
+            view->raise();
+            }
+      else {
+            raise(); // Console only, bring to top to see results.
+            }
       }
 
 //---------------------------------------------------------
@@ -364,7 +382,8 @@ void PluginCreator::closePlugin()
             view->close();
       if (dock)
             dock->close();
-      qInstallMsgHandler(0);
+      qInstallMessageHandler(0);
+      raise();
       }
 
 //---------------------------------------------------------
@@ -422,19 +441,20 @@ void PluginCreator::load()
 //   savePlugin
 //---------------------------------------------------------
 
-void PluginCreator::savePlugin()
+void PluginCreator::doSavePlugin(bool saveas) 
       {
-      if (created) {
+      if (saveas) {
             path = mscore->getPluginFilename(false);
             if (path.isEmpty())
                   return;
             }
       QFile f(path);
       QFileInfo fi(f);
+      msg(tr("Saving to:") + path + "\n");
       if(fi.suffix() != "qml" ) {
             QMessageBox::critical(mscore, tr("Save Plugin"), tr("Cannot determine file type"));
             return;
-      }
+            }
 
       if (f.open(QIODevice::WriteOnly)) {
             f.write(textEdit->toPlainText().toUtf8());
@@ -451,6 +471,16 @@ void PluginCreator::savePlugin()
       raise();
       }
 
+void PluginCreator::savePlugin()
+      {
+      doSavePlugin(created);
+      }
+
+void PluginCreator::savePluginAs()
+      {
+      doSavePlugin(true);
+      }
+
 //---------------------------------------------------------
 //   newPlugin
 //---------------------------------------------------------
@@ -476,6 +506,8 @@ void PluginCreator::newPlugin()
          "\n"
          "MuseScore {\n"
          "      menuPath: \"Plugins.pluginName\"\n"
+         "      description: \"Description goes here\"\n"
+         "      version: \"1.0\"\n"
          "      onRun: {\n"
          "            console.log(\"hello world\")\n"
          "            Qt.quit()\n"
