@@ -40,7 +40,6 @@
 ****************************************************************************/
 
 #include "svggenerator.h"
-#include "paintengine_p.h"
 
 ///////////////////////////////////////////////////////////////////////////////
 // FOR GRADIENT FUNCTIONALITY THAT IS NOT IMPLEMENTED (YET):
@@ -152,7 +151,7 @@ static QString getClass(const Ms::Element *e)
     return eName;
 }
 
-class SvgPaintEnginePrivate : public QPaintEnginePrivate
+class SvgPaintEnginePrivate
 {
 public:
     SvgPaintEnginePrivate()
@@ -231,6 +230,7 @@ class SvgPaintEngine : public QPaintEngine
 private:
     QString     stateString;
     QTextStream stateStream;
+    SvgPaintEnginePrivate *d_ptr;
 
 // Qt translates everything. These help avoid SVG transform="translate()".
     qreal _dx;
@@ -311,10 +311,10 @@ protected:
 
 public:
     SvgPaintEngine()
-        : QPaintEngine(*new SvgPaintEnginePrivate,
-                       svgEngineFeatures()),
+        : QPaintEngine(svgEngineFeatures()),
           stateStream(&stateString)
     {
+        d_ptr = new SvgPaintEnginePrivate;
     }
 
     bool begin(QPaintDevice *device);
@@ -1038,10 +1038,10 @@ bool SvgPaintEngine::begin(QPaintDevice *)
                 " xmlns:xlink=\"http://www.w3.org/1999/xlink\""
                 " version=\"1.2\" baseProfile=\"tiny\">" << endl;
     if (!d->attributes.title.isEmpty()) {
-        stream() << SVG_TITLE_BEGIN << d->attributes.title << SVG_TITLE_END << endl;
+        stream() << SVG_TITLE_BEGIN << d->attributes.title.toHtmlEscaped() << SVG_TITLE_END << endl;
     }
     if (!d->attributes.description.isEmpty()) {
-        stream() << SVG_DESC_BEGIN  << d->attributes.description << SVG_DESC_END << endl;
+        stream() << SVG_DESC_BEGIN  << d->attributes.description.toHtmlEscaped() << SVG_DESC_END << endl;
     }
 
 // <defs> is currently empty. It's necessary for gradients.
