@@ -1,9 +1,15 @@
-QT_TRANSLATE_NOOP("InstrumentsXML", "Common instruments"),
-QT_TRANSLATE_NOOP("InstrumentsXML", "Jazz instruments"),
-QT_TRANSLATE_NOOP("InstrumentsXML", "Orchestral instruments"),
-QT_TRANSLATE_NOOP("InstrumentsXML", "Early music"),
-QT_TRANSLATE_NOOP("InstrumentsXML", "Ethnic instruments"),
-QT_TRANSLATE_NOOP("InstrumentsXML", "Woodwind"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Common"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Pop/Rock"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Jazz"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Choral"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Orchestra"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Concert Band"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Marching Band"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Electronic Music"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "World Music"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Early Music"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Classroom"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Woodwinds"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Winds"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "W.", "Winds"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Piccolo"),
@@ -503,11 +509,11 @@ QT_TRANSLATE_NOOP3("InstrumentsXML", "Rg. Dng.", "Rag Dung"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Bugle"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Bu.", "Bugle"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Bugle"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Sop. Bu.", "Soprano Bugle"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Sop.", "Soprano Bugle"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Bugle"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Alt. Bu.", "Alto Bugle"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Alto", "Alto Bugle"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Baritone Bugle"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Bar. Bu.", "Baritone Bugle"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Bari.", "Baritone Bugle"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Flugelhorn"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Flghn.", "Flugelhorn"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Fiscorn"),
@@ -515,13 +521,13 @@ QT_TRANSLATE_NOOP3("InstrumentsXML", "Fsc.", "Fiscorn"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Kuhlohorn"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Klhn.", "Kuhlohorn"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Euphonium Bugle"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Euph. Bu.", "Euphonium Bugle"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Euph.", "Euphonium Bugle"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Mellophone Bugle"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Mel. Bu.", "Mellophone Bugle"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Mello", "Mellophone Bugle"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Contrabass Bugle"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Con. Bu.", "Contrabass Bugle"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Contra", "Contrabass Bugle"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Mellophone"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Mph.", "Mellophone"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Mello", "Mellophone"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Ophicleide"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Oph.", "Ophicleide"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "F Alto Ophicleide"),
@@ -618,23 +624,23 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "Shofar"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Sho.", "Shofar"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Vuvuzela"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Vuv.", "Vuvuzela"),
-QT_TRANSLATE_NOOP("InstrumentsXML", "Pitched Percussion"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Percussion - Pitched"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Timpani"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Timp.", "Timpani"),
-QT_TRANSLATE_NOOP("InstrumentsXML", "Roto-toms"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Rt-t.", "Roto-toms"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Roto-Toms"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Roto", "Roto-Toms"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Glockenspiel"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Glk.", "Glockenspiel"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Glock.", "Glockenspiel"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Orff Soprano Glockenspiel"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "O. S. Glk.", "Orff Soprano Glockenspiel"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Orff Alto Glockenspiel"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "O. A. Glk.", "Orff Alto Glockenspiel"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Crotales"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Cro.", "Crotales"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Crot.", "Crotales"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Tubaphone"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Tph.", "Tubaphone"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Almglocken"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Agl.", "Almglocken"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Almg.", "Almglocken"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Vibraphone"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Vib.", "Vibraphone"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Metallophone"),
@@ -645,8 +651,8 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "Orff Alto Metallophone"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "O. A. Met.", "Orff Alto Metallophone"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Orff Bass Metallophone"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "O. B. Met.", "Orff Bass Metallophone"),
-QT_TRANSLATE_NOOP("InstrumentsXML", "Tubular Bells"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Tu. Be.", "Tubular Bells"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Chimes"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Cme.", "Chimes"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Steel Drums"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "St. Dr.", "Steel Drums"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Steel Drums"),
@@ -664,7 +670,7 @@ QT_TRANSLATE_NOOP3("InstrumentsXML", "B. St. Dr.", "Bass Steel Drums"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Hand Bells"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Ha. Be.", "Hand Bells"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Tuned Gongs"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Td. Go.", "Tuned Gongs"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Td. Gon.", "Tuned Gongs"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Flexatone"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Flt.", "Flexatone"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Musical Saw"),
@@ -703,25 +709,25 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "Treble Kalimba"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Tr. Kal.", "Treble Kalimba"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Kalimba"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "A. Kal.", "Alto Kalimba"),
-QT_TRANSLATE_NOOP("InstrumentsXML", "Unpitched Percussion"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Percussion - Unpitched"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Drumset"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Drs.", "Drumset"),
-QT_TRANSLATE_NOOP("InstrumentsXML", "Snare Drum"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Sn. Dr.", "Snare Drum"),
-QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Drum"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "B. Dr.", "Bass Drum"),
-QT_TRANSLATE_NOOP("InstrumentsXML", "Piccolo Snare Drum"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "P. Sn. Dr.", "Piccolo Snare Drum"),
-QT_TRANSLATE_NOOP("InstrumentsXML", "Military Drum"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Mil. Dr.", "Military Drum"),
-QT_TRANSLATE_NOOP("InstrumentsXML", "Tom Toms"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Toms", "Tom Toms"),
-QT_TRANSLATE_NOOP("InstrumentsXML", "Chinese Tom-toms"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Ch. To.", "Chinese Tom-toms"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "D. Set", "Drumset"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Concert Snare Drum"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Con. Sn.", "Concert Snare Drum"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Concert Bass Drum"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Con. BD ", "Concert Bass Drum"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Piccolo Snare"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Picc. Sn.", "Piccolo Snare"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Field Drum"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Field Dr.", "Field Drum"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Concert Toms"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "C. Toms", "Concert Toms"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Chinese Tom-Toms"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Ch. Toms", "Chinese Tom-Toms"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Bongos"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Bo.", "Bongos"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Bon.", "Bongos"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Congas"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Co.", "Congas"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Con.", "Congas"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Timbales"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Timb.", "Timbales"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Frame Drum"),
@@ -734,8 +740,8 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "Finger Cymbals"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Fi. Cym.", "Finger Cymbals"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Hi-hat"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Hi-hat", "Hi-hat"),
-QT_TRANSLATE_NOOP("InstrumentsXML", "Tam-tam"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Tam-tam", "Tam-tam"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Tam-Tam"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Tam", "Tam-Tam"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Bells"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Be.", "Bells"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Sleigh Bells"),
@@ -743,7 +749,7 @@ QT_TRANSLATE_NOOP3("InstrumentsXML", "Sle. Be.", "Sleigh Bells"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Bell Plate"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Be. Pla.", "Bell Plate"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Bowl Gongs"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Bw. Go.", "Bowl Gongs"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Bw. Gon.", "Bowl Gongs"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Tubo"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Tu.", "Tubo"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Metal Castanets"),
@@ -783,7 +789,7 @@ QT_TRANSLATE_NOOP3("InstrumentsXML", "Gro.", "Güiro"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Maracas"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Mrcs.", "Maracas"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Cabasa"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Cab.", "Cabasa"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Cabs.", "Cabasa"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Quijada"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Qui.", "Quijada"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Vibraslap"),
@@ -810,19 +816,11 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "Shell Wind Chimes"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Sh. Wn Ch.", "Shell Wind Chimes"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Stones"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Sto.", "Stones"),
-QT_TRANSLATE_NOOP("InstrumentsXML", "Finger Snap"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Fi. Sna.", "Finger Snap"),
-QT_TRANSLATE_NOOP("InstrumentsXML", "Hand Clap"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Hd. Clp.", "Hand Clap"),
-QT_TRANSLATE_NOOP("InstrumentsXML", "Slap"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Sla.", "Slap"),
-QT_TRANSLATE_NOOP("InstrumentsXML", "Stamp"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Sta.", "Stamp"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Tambourine"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Tamb.", "Tambourine"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Percussion"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Perc.", "Percussion"),
-QT_TRANSLATE_NOOP("InstrumentsXML", "Battery Percussion"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Percussion - Marching"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Snare Drum"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "S.D.", "Snare Drum"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Drums"),
@@ -831,6 +829,15 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Drums"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "B.D.", "Bass Drums"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Cymbals"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Cym.", "Cymbals"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Percussion - Body"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Finger Snap"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Fi. Sna.", "Finger Snap"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Hand Clap"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Hd. Clp.", "Hand Clap"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Slap"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Sla.", "Slap"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Stamp"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Sta.", "Stamp"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Vocals"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Voice"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Vo.", "Voice"),
@@ -896,7 +903,7 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "Harmonium"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Harm.", "Harmonium"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Reed Organ"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Rd. Org.", "Reed Organ"),
-QT_TRANSLATE_NOOP("InstrumentsXML", "Electronic Instruments"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Electronic"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Effect Synthesizer"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Synth.", "Effect Synthesizer"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "rain"),
@@ -975,7 +982,7 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "Theremin"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Thmn.", "Theremin"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Percussion Synthesizer"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Perc. Syn.", "Percussion Synthesizer"),
-QT_TRANSLATE_NOOP("InstrumentsXML", "Plucked Strings"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Strings - Plucked"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Banjo"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Bj.", "Banjo"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Banjo [Tablature]"),
@@ -1021,6 +1028,12 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "Guitar"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Guit.", "Guitar"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Guitar (Treble Clef)"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Classical Guitar [Tablature]"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "7-string Guitar"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Guit.", "7-string Guitar"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "7-string Guitar [Tablature]"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Cavaquinho"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Cava.", "Cavaquinho"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Cavaquinho [Tablature]"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Baritone Guitar"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Bar. Guit.", "Baritone Guitar"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Contra Guitar"),
@@ -1149,7 +1162,7 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "Bugarija"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Bu.", "Bugarija"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Berda"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Be.", "Berda"),
-QT_TRANSLATE_NOOP("InstrumentsXML", "Strings"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Strings - Bowed"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Strings"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "St.", "Strings"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
